#ifndef BS_STRUCTURE_VIEW_H
#define BS_STRUCTURE_VIEW_H

#include <QGraphicsView>
#include <QImage>
#include "bsstructureitem.h"


class BSStructureView : public QGraphicsView
{

public:

  /**
   * \brief Creates a pixel analyzer.
   */
  BSStructureView (QImage *im, BSDetector *sd);

  /**
   * \brief Deletes the pixel analyzer.
   */
  ~BSStructureView ();

  /**
   * Sets the gradient image.
   */
  void setGradientImage (VMap *gMap);

  /**
   * Sets the examined segment from a multi-selection.
   */
  inline void setExamined (int index) { grid->setExamined (index); }

  /**
   * Toggles the window background between the current image or plain white.
   */
  void toggleBackground ();

  /**
   * Toggles the current image between gray level or gradient image.
   */
  void toggleGradient ();

  /**
   * \brief Redraws the pixel analyzer.
   */
  void paint (QPainter *painter,
              const QStyleOptionGraphicsItem *option, QWidget *widget);

  /**
   * \brief Processes key pressed events.
   */
  bool processKeyEvent (QKeyEvent *event);

protected:

private:


  /** Pointer to the blurred segment detector. */
  BSDetector *det;
  /** Pointer to the raw image. */
  QImage *graylevelImage;
  /** Pointer to the blurred segment structure graphics item. */
  BSStructureItem *grid;
  /** Background image. */
  QImage image;
  /** Background image display modality. */
  bool imageInBack;
  /** Pointer to the gradient image. */
  QImage *currentImage;
  /** Pointer to the currently displayed image. */
  QImage *gradImage;
  /** Gradient image display modality. */
  bool gradInBack;

  /**
   * Updates the background image.
   * @param zoomChanged If 'true', the zoom factorshould be taken into account
   */
  void updateBackground (bool zoomChanged);

};

#endif
